@@ -5,7 +5,7 @@ use Catmandu::Fix::LIDO::Value qw(emit_base_value);
 
 use strict;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Exporter qw(import);
 
@@ -126,3 +126,42 @@ Catmandu::Fix::LIDO::Nameset::emit_nameset
 =head1 DESCRIPTION
 
 This function will generate the necessary emit code to generate a C<nameset> node, consisting of C<appellationValue> and C<sourceAppellation>, in a given path. The node is attached directly to the path, so you must specify the name of the nameset (e.g. titleSet) in the $path.
+
+=head2 MULTIPLE INSTANCES
+
+Multiple instances can be created in two ways, depending on whether you want to repeat the parent element or not.
+
+If you do not want to repeat the parent element, call the function multiple times with the same C<path>. Multiple C<appellationValue> and C<sourceAppellation> tags will be created on the same level.
+
+If you do want to repeat the parent element (to keep related C<appellationValue> and C<sourceAppellation> together), add an C<$append> to your path for all calls.
+
+=head1 SEE ALSO
+
+L<Catmandu::LIDO> and L<Catmandu>
+
+=head1 AUTHORS
+
+=over
+
+=item Pieter De Praetere, C<< pieter at packed.be >>
+
+=back
+
+=head1 CONTRIBUTORS
+
+=over
+
+=item Pieter De Praetere, C<< pieter at packed.be >>
+
+=item Matthias Vandermaesen, C<< matthias.vandermaesen at vlaamsekunstcollectie.be >>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+The Perl software is copyright (c) 2016 by PACKED vzw and VKC vzw.
+This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.
+
+=encoding utf8
+
+=cut
\ No newline at end of file
