@@ -8,12 +8,10 @@ use Catmandu::Fix::LIDO::Value qw(emit_base_value);
 
 use strict;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 #https://librecatproject.wordpress.com/2014/03/26/create-a-fixer-part-2/
 
-use Data::Dumper qw(Dumper);
-
 with 'Catmandu::Fix::Base';
 
 has path => (fix_arg => 1);
@@ -49,10 +47,10 @@ Catmandu::Fix::lido_basevalue - Create a basic XML node in a C<path>
     lido_basevalue(
         path,
         value,
-        -pref: node.pref,
-        -lang: node.lang,
+        -pref:  node.pref,
+        -lang:  node.lang,
         -label: node.label,
-        -type: node.type
+        -type:  node.type
     )
 
 =head1 DESCRIPTION
@@ -109,3 +107,34 @@ All optional parameters are strings.
             </lido:subjectWrap>
         </lido:objectRelationWrap>
     </lido:descriptiveMetadata>
+
+=head1 SEE ALSO
+
+L<Catmandu::LIDO> and L<Catmandu>
+
+=head1 AUTHORS
+
+=over
+
+=item Pieter De Praetere, C<< pieter at packed.be >>
+
+=back
+
+=head1 CONTRIBUTORS
+
+=over
+
+=item Pieter De Praetere, C<< pieter at packed.be >>
+
+=item Matthias Vandermaesen, C<< matthias.vandermaesen at vlaamsekunstcollectie.be >>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+The Perl software is copyright (c) 2016 by PACKED vzw and VKC vzw.
+This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.
+
+=encoding utf8
+
+=cut
\ No newline at end of file
