@@ -8,17 +8,15 @@ use Catmandu::Fix::LIDO::DescriptiveNote qw(emit_descriptive_note);
 
 use strict;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 #https://librecatproject.wordpress.com/2014/03/26/create-a-fixer-part-2/
 
-use Data::Dumper qw(Dumper);
-
 with 'Catmandu::Fix::Base';
 
-has path => (fix_arg => 1);
+has path  => (fix_arg => 1);
 has value => (fix_arg => 1);
-has lang => (fix_opt => 1);
+has lang  => (fix_opt => 1);
 has label => (fix_opt => 1);
 
 sub emit {
@@ -59,7 +57,7 @@ Catmandu::Fix::lido_descriptivenote - create a C<descriptiveNoteValue> in a C<pa
     lido_descriptivenote(
         path,
         value,
-        -lang: descriptiveNoteValue.lang,
+        -lang:  descriptiveNoteValue.lang,
         -label: descriptiveNoteValue.label
     )
 
@@ -67,7 +65,7 @@ Catmandu::Fix::lido_descriptivenote - create a C<descriptiveNoteValue> in a C<pa
 
 Creates a C<descriptiveNoteValue> in a C<path>.
 
-=head2 Parameters
+=head2 PARAMETERS
 
 =head3 Required parameters
 
@@ -93,6 +91,10 @@ All optional parameters are strings.
 
 =back
 
+=head2 MULTIPLE INSTANCES
+
+To add multiple C<descriptiveNoteValue>'s at the same location (e.g. C<descriptiveMetadata.objectDescriptionWrap.objectDescriptionSet>), simply call the fix multiple times with the same path. A new parent (e.g. C<objectDescriptionSet>) will be created for every new C<descriptiveNoteValue>, per the standard.
+
 =head1 EXAMPLE
 
 =head2 Fix
@@ -100,7 +102,8 @@ All optional parameters are strings.
     lido_descriptivenote(
         descriptiveMetadata.eventWrap.eventSet.$last.event.eventDescriptionSet,
         recordList.record.creation_desc,
-        -lang: nl
+        -lang:  nl,
+        -label: Default
     )
 
 =head2 Result
@@ -109,9 +112,40 @@ All optional parameters are strings.
             <lido:eventSet>
                 <lido:event>
                     <lido:eventDescriptionSet>
-                        <lido:descriptiveNoteValue xml:lang="nl">Een generieke beschrijving.</lido:descriptiveNoteValue>
+                        <lido:descriptiveNoteValue xml:lang="nl" lido:label="Default">Een generieke beschrijving.</lido:descriptiveNoteValue>
                     </lido:eventDescriptionSet>
                 </lido:event>
             </lido:eventSet>
         </lido:eventWrap>
     </lido:descriptiveMetadata>
+
+=head1 SEE ALSO
+
+L<Catmandu::LIDO> and L<Catmandu>
+
+=head1 AUTHORS
+
+=over
+
+=item Pieter De Praetere, C<< pieter at packed.be >>
+
+=back
+
+=head1 CONTRIBUTORS
+
+=over
+
+=item Pieter De Praetere, C<< pieter at packed.be >>
+
+=item Matthias Vandermaesen, C<< matthias.vandermaesen at vlaamsekunstcollectie.be >>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+The Perl software is copyright (c) 2016 by PACKED vzw and VKC vzw.
+This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.
+
+=encoding utf8
+
+=cut
\ No newline at end of file
